package com.huimv.farm.musk.breed.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.breed.entity.BreedCure;
import com.huimv.farm.musk.breed.entity.BreedInspect;
import com.huimv.farm.musk.breed.mapper.BreedCureMapper;
import com.huimv.farm.musk.breed.service.IBreedCureService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 治疗登记 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class BreedCureServiceImpl extends ServiceImpl<BreedCureMapper, BreedCure> implements IBreedCureService {

    @Autowired
    private BreedCureMapper cureMapper;
    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String muskId = paramsMap.get("muskId");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        QueryWrapper<BreedCure> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).like(StringUtils.isNotBlank(muskId), "musk_id", muskId);
        Page page = new Page<BreedCure>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, cureMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result add(BreedCure cure) {
        cure.setCreateTime(new Date());
        return new Result(ResultCode.SUCCESS, cureMapper.insert(cure));
    }

    @Override
    public Result edit(BreedCure cure) {
        return new Result(ResultCode.SUCCESS, cureMapper.updateById(cure));
    }

    @Override
    public Result remove(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            cureMapper.deleteById(s);
        }
        return new Result(ResultCode.SUCCESS);
    }
}
