package com.huimv.farm.musk.breed.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.breed.entity.BreedLeave;
import com.huimv.farm.musk.breed.entity.BreedTransfer;
import com.huimv.farm.musk.breed.mapper.BreedLeaveMapper;
import com.huimv.farm.musk.breed.service.IBreedLeaveService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 离场登记 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class BreedLeaveServiceImpl extends ServiceImpl<BreedLeaveMapper, BreedLeave> implements IBreedLeaveService {

    @Autowired
    private BreedLeaveMapper leaveMapper;
    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String muskId = paramsMap.get("muskId");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        QueryWrapper<BreedLeave> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).like(StringUtils.isNotBlank(muskId), "musk_id", muskId);
        Page page = new Page<BreedLeave>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, leaveMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result add(BreedLeave breedLeave) {
        breedLeave.setCreateTime(new Date());
        return new Result(ResultCode.SUCCESS, leaveMapper.insert(breedLeave));
    }

    @Override
    public Result edit(BreedLeave breedLeave) {
        return new Result(ResultCode.SUCCESS, leaveMapper.updateById(breedLeave));
    }

    @Override
    public Result remove(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            leaveMapper.deleteById(s);
        }
        return new Result(ResultCode.SUCCESS);
    }
}
