package com.huimv.farm.musk.breed.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.breed.entity.BreedMedicine;
import com.huimv.farm.musk.breed.entity.BreedVaccination;
import com.huimv.farm.musk.breed.mapper.BreedMedicineMapper;
import com.huimv.farm.musk.breed.mapper.BreedVaccinationMapper;
import com.huimv.farm.musk.breed.service.IBreedMedicineService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 群体用药登记 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class BreedMedicineServiceImpl extends ServiceImpl<BreedMedicineMapper, BreedMedicine> implements IBreedMedicineService {

    @Autowired
    private BreedMedicineMapper medicineMapper;

    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String medicine = paramsMap.get("medicine");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        QueryWrapper<BreedMedicine> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).like(StringUtils.isNotBlank(medicine), "medicine", medicine);
        Page page = new Page<BreedMedicine>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, medicineMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result add(BreedMedicine medicine) {
        medicine.setCreateTime(new Date());
        return new Result(ResultCode.SUCCESS, medicineMapper.insert(medicine));
    }

    @Override
    public Result edit(BreedMedicine medicine) {
        return new Result(ResultCode.SUCCESS, medicineMapper.updateById(medicine));
    }

    @Override
    public Result remove(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            medicineMapper.deleteById(s);
        }
        return new Result(ResultCode.SUCCESS);
    }
}
