package com.huimv.farm.musk.breed.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.breed.entity.BreedMuskInfo;
import com.huimv.farm.musk.breed.entity.MuskEarmark;
import com.huimv.farm.musk.breed.mapper.BreedMuskInfoMapper;
import com.huimv.farm.musk.breed.mapper.MuskEarmarkMapper;
import com.huimv.farm.musk.breed.service.IBreedMuskInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 档案登记 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class BreedMuskInfoServiceImpl extends ServiceImpl<BreedMuskInfoMapper, BreedMuskInfo> implements IBreedMuskInfoService {

    @Autowired
    private BreedMuskInfoMapper muskInfoMapper;
    @Autowired
    private MuskEarmarkMapper earmarkMapper;


    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String muskId = paramsMap.get("muskId");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        QueryWrapper<BreedMuskInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).like(StringUtils.isNotBlank(muskId), "musk_id", muskId);
        Page page = new Page<BreedMuskInfo>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, muskInfoMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result add(BreedMuskInfo muskInfo) {
        Integer count = muskInfoMapper.selectCount(new QueryWrapper<BreedMuskInfo>().eq("farm_id", muskInfo.getFarmId()).eq("musk_id", muskInfo.getMuskId()));
        if (count != 0) {
            return new Result(10001, "添加失败！林麝id编号已存在！", false);
        }
        MuskEarmark earmark = earmarkMapper.selectOne(new QueryWrapper<MuskEarmark>().eq("earmark", muskInfo.getMuskId()));
        if (ObjectUtil.isNotEmpty(earmark)) {
            earmark.setIsUse(1);
            earmarkMapper.updateById(earmark);
        }
        Date date = new Date();
        long l = date.getTime() - muskInfo.getBirthDate().getTime();
        long l1 = l / (24 * 60 * 60 * 1000);
        muskInfo.setDayNum((int) l1);
        muskInfoMapper.insert(muskInfo);
        return new Result(ResultCode.SUCCESS);
    }

    @Override
    public Result edit(BreedMuskInfo muskInfo) {
        String sheepId = muskInfo.getMuskId();
        int count = muskInfoMapper.selectCount(new QueryWrapper<BreedMuskInfo>().eq("musk_id", sheepId).ne("id", muskInfo.getId()));
        if (count > 0) {
            return new Result(10001, "修改失败，羊只档案已存在", false);
        }
        muskInfoMapper.updateById(muskInfo);
        return new Result(10000, "修改成功！", true);
    }

    @Override
    public Result remove(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            BreedMuskInfo muskInfo = muskInfoMapper.selectById(s);
            if (muskInfo.getIsLeave() == 1) {
                return new Result(10001, "删除失败！林麝未离场暂不可删除", false);
            }
            MuskEarmark earmark = earmarkMapper.selectOne(new QueryWrapper<MuskEarmark>().eq("earmark", muskInfo.getMuskId()));
            if (ObjectUtil.isNotEmpty(earmark)) {
                earmark.setIsUse(0);
                earmarkMapper.updateById(earmark);
            }
            muskInfoMapper.deleteById(s);
        }
        return new Result(10000, "删除成功！", true);
    }
}
