package com.huimv.farm.musk.breed.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huimv.farm.musk.breed.entity.BreedMuskInfo;
import com.huimv.farm.musk.breed.entity.BreedMuskStock;
import com.huimv.farm.musk.breed.mapper.BreedMuskStockMapper;
import com.huimv.farm.musk.breed.service.IBreedMuskStockService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.farm.musk.common.utils.Result;
import com.huimv.farm.musk.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Map;

/**
 * <p>
 * 存栏统计 服务实现类
 * </p>
 *
 * @author author
 * @since 2024-09-02
 */
@Service
public class BreedMuskStockServiceImpl extends ServiceImpl<BreedMuskStockMapper, BreedMuskStock> implements IBreedMuskStockService {

    @Autowired
    private BreedMuskStockMapper stockMapper;
    @Override
    public Result listPage(Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String pageNum = paramsMap.get("pageNum");
        String pageSize = paramsMap.get("pageSize");
        String stage = paramsMap.get("stage");
        if ("".equals(pageNum) || null == pageNum) {
            pageNum = "1";
            pageSize = "20";
        }
        QueryWrapper<BreedMuskStock> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId).eq(StringUtils.isNotBlank(stage), "stage", stage);
        Page page = new Page<BreedMuskStock>(Integer.parseInt(pageNum), Integer.parseInt(pageSize));
        return new Result(ResultCode.SUCCESS, stockMapper.selectPage(page, queryWrapper));
    }

    @Override
    public Result add(BreedMuskStock muskStock) {
        muskStock.setCreateTime(new Date());
        return new Result(ResultCode.SUCCESS, stockMapper.insert(muskStock));
    }

    @Override
    public Result edit(BreedMuskStock muskStock) {
        return new Result(ResultCode.SUCCESS, stockMapper.updateById(muskStock));
    }

    @Override
    public Result remove(Map<String, String> paramsMap) {
        String ids = paramsMap.get("ids");
        String[] split = ids.split(",");
        for (String s : split) {
            stockMapper.deleteById(s);
        }
        return new Result(ResultCode.SUCCESS);
    }

}
